@@ -1,23 +1,18 @@
 #include "UnlockableItem.h"
 
-#include "../util/Logger.h"
 #include "../util/CheckSums.h"
+#include "../util/Logger.h"
 
 
-UnlockableItem::UnlockableItem() :
-    type(INVALID_UNLOCKABLE_ITEM_TYPE),
-    name()
-{}
-
-std::string UnlockableItem::Dump(unsigned short ntabs) const {
+std::string UnlockableItem::Dump(uint8_t ntabs) const {
     std::string retval = "Item type = ";
     switch (type) {
-    case UIT_BUILDING:      retval += "Building";   break;
-    case UIT_SHIP_PART:     retval += "ShipPart";   break;
-    case UIT_SHIP_HULL:     retval += "ShipHull";   break;
-    case UIT_SHIP_DESIGN:   retval += "ShipDesign"; break;
-    case UIT_TECH:          retval += "Tech"    ;   break;
-    default:                retval += "?"       ;   break;
+    case UnlockableItemType::UIT_BUILDING:    retval += "Building";   break;
+    case UnlockableItemType::UIT_SHIP_PART:   retval += "ShipPart";   break;
+    case UnlockableItemType::UIT_SHIP_HULL:   retval += "ShipHull";   break;
+    case UnlockableItemType::UIT_SHIP_DESIGN: retval += "ShipDesign"; break;
+    case UnlockableItemType::UIT_TECH:        retval += "Tech"    ;   break;
+    default:                                  retval += "?"       ;   break;
     }
     retval += " name = \"" + name + "\"\n";
     return retval;
@@ -33,7 +28,7 @@ bool operator!=(const UnlockableItem& lhs, const UnlockableItem& rhs)
 
 
 namespace CheckSums {
-    void CheckSumCombine(unsigned int& sum, const UnlockableItem& item) {
+    void CheckSumCombine(uint32_t& sum, const UnlockableItem& item) {
         TraceLogger() << "CheckSumCombine(Slot): " << typeid(item).name();
         CheckSumCombine(sum, item.type);
         CheckSumCombine(sum, item.name);
